/* ----------------------------------------------------------------------------
 * Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
 * ON Semiconductor), All Rights Reserved
 *
 * This code is the property of ON Semiconductor and may not be redistributed
 * in any form without prior written permission from ON Semiconductor.
 * The terms of use and warranty for this code are covered by contractual
 * agreements between ON Semiconductor and the licensee.
 *
 * This is Reusable Code.
 *
 * ------------------------------------------------------------------------- */

#include "io/io.h"
#include "ioBase.h"

/* ----------------------------------------------------------------------------
 * Function     : ioParameters
 * ----------------------------------------------------------------------------
 * Description  : Delegate method to fetch the operational parameters from
 *                the IO control block
 * Inputs       : provider : a pointer to an IO Provider
 * Outputs      : a void pointer which can be used to access the operational
 *                parameters block
 * Assumptions  : None
 * ------------------------------------------------------------------------- */
void * ioParameters(pIOProvider provider)
{
    pSourceSink object = (pSourceSink)provider;
    return &object->operation;
}

/* ----------------------------------------------------------------------------
 * Function     : ioRead
 * ----------------------------------------------------------------------------
 * Description  : Delegate method to fetch data from the specified IO
 *                provider
 * Inputs       : source : A pointer to the IO provider
 *                buffer : A buffer into which the data being read should be
 *                placed
 *                maxsize : the maximum size of the data to be read
 * Outputs      : None
 * Assumptions  : None
 * ------------------------------------------------------------------------- */
uint32_t ioRead(pIOProvider source, char *buffer, uint32_t maxsize)
{
    pSourceSink object = (pSourceSink)source;
    object->read(object, buffer, maxsize);
    return object->srcUsed;
}

/* ----------------------------------------------------------------------------
 * Function     : ioWrite
 * ----------------------------------------------------------------------------
 * Description  : Delegate method to send data to the specified IO provider
 * Inputs       : source : A pointer to the IO provider
 *                buffer : A buffer from which the data being sent read
 *                should be read
 *                size : the maximum size of the data to be sent
 * Outputs      : None
 * Assumptions  : None
 * ------------------------------------------------------------------------- */
uint32_t ioWrite(pIOProvider sink, char *buffer, uint32_t size)
{
    pSourceSink object = (pSourceSink)sink;
    object->write(object, buffer, size);
    return object->snkUsed;
}
