/* ----------------------------------------------------------------------------
 * Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
 * ON Semiconductor), All Rights Reserved
 *
 * This code is the property of ON Semiconductor and may not be redistributed
 * in any form without prior written permission from ON Semiconductor.
 * The terms of use and warranty for this code are covered by contractual
 * agreements between ON Semiconductor and the licensee.
 *
 * This is Reusable Code.
 *
 * ------------------------------------------------------------------------- */

#include <rsl10.h>
#include <rsl10_reg.h>
#include <rsl10_hw.h>

#include "lpdsp32_JTAG.h"

/* define the pins required for configuring the LPDSP32 JTAG connection */
#define JTAG_LPDSP32_TCK (1)
#define JTAG_LPDSP32_TDI (2)
#define JTAG_LPDSP32_TDO (3)
#define JTAG_LPDSP32_TMS (4)

/* ----------------------------------------------------------------------------
 * Function     : configureGPIOForJTAG
 * ----------------------------------------------------------------------------
 * Description  : This function will configure GPIOs to allow the JTAG on
 *                the LPDSP32 to be used.
 * Inputs       : None
 * Outputs      : None
 * Assumptions  : None
 * ------------------------------------------------------------------------- */
void configureGPIOForJTAG(void)
{
    /* Initialise the JTAG GPIOs, make sure they are doing what we expect */
    Sys_LPDSP32_DIOJTAG(DIO_WEAK_PULL_DOWN, JTAG_LPDSP32_TDI, JTAG_LPDSP32_TMS,
                        JTAG_LPDSP32_TCK, JTAG_LPDSP32_TDO);
}
