/* ----------------------------------------------------------------------------
 * Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
 * ON Semiconductor), All Rights Reserved
 *
 * This code is the property of ON Semiconductor and may not be redistributed
 * in any form without prior written permission from ON Semiconductor.
 * The terms of use and warranty for this code are covered by contractual
 * agreements between ON Semiconductor and the licensee.
 *
 * This is Reusable Code.
 *
 * ----------------------------------------------------------------------------
 * memset.c
 * ----------------------------------------------------------------------------
 * $Revision: 1.5 $
 * $Date: 2017/10/19 14:28:13 $
 * ------------------------------------------------------------------------- */

/* ----------------------------------------------------------------------------
 * Function      : void * memset32(void *s, int c, unsigned int n)
 * ----------------------------------------------------------------------------
 * Description   : Set 32-bit memory to a given preset value
 * Inputs        : - s  - Pointer to the destination
 *                 - c  - Value to use to set memory
 *                 - n  - Length of the data to write
 * Outputs       : return value - Pointer to the destination
 * Assumptions   : None
 * ------------------------------------------------------------------------- */
void * memset32(void *s, int c, unsigned int n)
{
    unsigned int i;
    unsigned int *temp = (unsigned int *)s;

    for (i = 0; i < n; i++)
    {
        temp[i] = (unsigned int) c;
    }
    return s;
}

/* ----------------------------------------------------------------------------
 * Function      : void * memset64(void *s, long long c, unsigned int n)
 * ----------------------------------------------------------------------------
 * Description   : Set 64-bit memory to a given preset value
 * Inputs        : - s  - Pointer to the destination
 *                 - c  - Value to use to set memory
 *                 - n  - Length of the data to write
 * Outputs       : return value - Pointer to the destination
 * Assumptions   : None
 * ------------------------------------------------------------------------- */
void * memset64(void *s, long long c, unsigned int n)
{
    unsigned int i;
    unsigned long long *temp = (unsigned long long *)s;

    for (i = 0; i < n; i++)
    {
        temp[i] = (unsigned long long) c;
    }
    return s;
}

/* ----------------------------------------------------------------------------
 * Function      : void * memcpy32(void *s1, const void *s2, unsigned int n)
 * ----------------------------------------------------------------------------
 * Description   : Copy 32-bit data from s2 to s1
 * Inputs        : - s1 - Pointer to the destination
 *                 - s2 - Pointer to the source
 *                 - n  - Length of the data to be copied
 * Outputs       : return value - Pointer to the destination
 * Assumptions   : None
 * ------------------------------------------------------------------------- */
void * memcpy32(void *s1, const void *s2, unsigned int n)
{
    unsigned int i;
    unsigned int *temp_d = (unsigned int *)s1;
    unsigned int *temp_s = (unsigned int *)s2;

    for (i = 0; i < n; i++)
    {
        temp_d[i] = temp_s[i];
    }
    return s1;
}

/* ----------------------------------------------------------------------------
 * Function      : void * memcpy64(void *s1, const void *s2, unsigned int n)
 * ----------------------------------------------------------------------------
 * Description   : Copy 64-bit data from s2 to s1
 * Inputs        : - s1 - Pointer to the destination
 *                 - s2 - Pointer to the source
 *                 - n  - Length of the data to be copied
 * Outputs       : return value - Pointer to the destination
 * Assumptions   : None
 * ------------------------------------------------------------------------- */
void * memcpy64(void *s1, const void *s2, unsigned int n)
{
    unsigned int i;
    unsigned long long *temp_d = (unsigned long long *)s1;
    unsigned long long *temp_s = (unsigned long long *)s2;

    for (i = 0; i < n; i++)
    {
        temp_d[i] = temp_s[i];
    }
    return s1;
}

/* ----------------------------------------------------------------------------
 * Function      : void * memmove32(void *s1, const void *s2, unsigned int n)
 * ----------------------------------------------------------------------------
 * Description   : Move 32-bit data from s2 to s1
 * Inputs        : - s1 - Pointer to the destination
 *                 - s2 - Pointer to the source
 *                 - n  - Length of the data to be copied
 * Outputs       : return value - Pointer to the destination
 * Assumptions   : s1 and s2 can overlap
 * ------------------------------------------------------------------------- */
void * memmove32(void *s1, const void *s2, unsigned int n)
{
    int i;
    unsigned int *temp_d = (unsigned int *) s1;
    unsigned int *temp_s = (unsigned int *) s2;

    if (temp_d <= temp_s)
    {
        for (i = 0; i < n; i++)
        {
            temp_d[i] = temp_s[i];
        }
    }
    else 
    {
        for (i = n - 1; i >= 0; i--)
        {
            temp_d[i] = temp_s[i];
        }
    
    }
    return s1;
}
