/* ----------------------------------------------------------------------------
 * Copyright (c) 2016-2017 Semiconductor Components Industries, LLC (d/b/a
 * ON Semiconductor), All Rights Reserved
 *
 * This code is the property of ON Semiconductor and may not be redistributed
 * in any form without prior written permission from ON Semiconductor.
 * The terms of use and warranty for this code are covered by contractual
 * agreements between ON Semiconductor and the licensee.
 *
 * This is Reusable Code.
 *
 * ----------------------------------------------------------------------------
 * rsl10_lpdsp32_vector.c
 * - LPDSP32 Interrupt helper functions implementations
 * ----------------------------------------------------------------------------
 * $Revision: 1.3 $
 * $Date: 2017/06/12 16:10:32 $
 * ------------------------------------------------------------------------- */

#include <rsl10_lpdsp32_vector.h>

/* ----------------------------------------------------------------------------
 * Function    : unsigned int enable_interrupt(unsigned int index)
 * ----------------------------------------------------------------------------
 * Description : Enable the specified interrupt
 * Inputs      : index          - Interrupt to disable
 * Outputs     : return value   - 0 if the requested interrupt is out of
 *                                bounds, 1 otherwise
 * Assumptions : None
 * -------------------------------------------------------------------------*/
unsigned int enable_interrupt(unsigned int index)
{
    int current_mask = get_interrupt_mask();

    if ((index > 14) || (index < 0))
    {
        return 0;
    }

    current_mask = current_mask | (1 << index);
    set_interrupt_mask(current_mask);
    return 1;
}

/* ----------------------------------------------------------------------------
 * Function    : unsigned int disable_interrupt(unsigned int index)
 * ----------------------------------------------------------------------------
 * Description : Disable the specified interrupt
 * Inputs      : index          - Interrupt to disable
 * Outputs     : return value   - 0 if the requested interrupt is out of
 *                                bounds, 1 otherwise
 * Assumptions : None
 * ------------------------------------------------------------------------- */
unsigned int disable_interrupt(unsigned int index)
{
    int current_mask = get_interrupt_mask();

    if ((index > 14) || (index < 0))
    {
        return 0;
    }

    current_mask = current_mask & ~(1 << index);
    set_interrupt_mask(current_mask);
    return 1;
}
