
Fibonacci LPDSP32 Sample Application
====================================

This application consists of two sub-projects:
1. The `Fibonacci_CM3` project
2. The `Fibonacci_LPDSP32` project

NOTE: The ChessDE and ON Semiconductor IDE are used to build and debug both
the Arm Cortex-M3 core and LPDSP32 projects.

The purpose of this application is to show how the Arm Cortex-M3 and LPDSP32 
cores can communicate and share information. The application runs on the 
Arm Cortex-M3 core, but it delegates some math processing to the LPDSP32. A 
shared memory is used to pass context between the cores, and interrupts
are used to notify that there is work to be done, or that work has been 
completed.

This application calculates Fibonacci numbers when the user button is pressed 
on the evaluation board. Each time the button is pressed, the next number in 
the sequence is calculated. The code in the Arm Cortex-M3 processor project 
handles the button (DIO5) presses, and tells the LPDSP32 which sequence number 
to calculate (via the `CM3_0` interrupt). The code in the LPDSP32 project 
calculates the requested sequence number and passes it back to the 
Arm Cortex-M3 core. Two 32-bit words in the shared memory are used to pass the 
information back and forth; both words are defined as `uint32_t`. The 
Arm Cortex-M3 core notifies the LPDSP32 that there is data requested via an 
interrupt; the LPDSP32 reciprocates by raising an interrupt on the 
Arm Cortex-M3 core when the number has been calculated.

This application can be executed on any Evaluation and Development Board.

For the purposes of this sample, the expectation is that an external JLink
JTAG programmer will be used to communicate with the JTAG port for the 
LPDSP32.

When connecting the JLink programmer to the board, the following connections
must be made, note that these DIO numbers correspond to the ones being set up
in main.c:

    JLink Connector          Evaluation and Development Board
    
        GND     (4)                 GND
        VTRef   (1)                 VBAT_OUT
        TCK     (9)                 DIO 1
        TDI     (5)                 DIO 2
        TDO     (13)                DIO 3
        TMS     (7)                 DIO 4

The ON Semiconductor IDE communicates with the JLink programmer that is
connected to the Arm Cortex-M3 processor to program this core. To debug
code on LPDSP32, the ASIP programmer and the ChessDE is used. For this
purpose, the JTalk utility must be run to maintain communication between
the external JTAG (JLink) programmer and the LPDSP32 core. JTalk is a piece of
software provided by Synopsys, and used to create a channel between the ASIP 
programmer and the hardware through JLink.

JTalk Command:

> jtalk.exe -c jlink -f 2000

For more information, see the comments in the code.

The code files are organized as follows:

Arm Cortex-M3 processor:

- `main.c`           : main file, containing the Arm Cortex-M3 processor 
                       memory allocation and interrupt handles
- `sections.ld`      : linker script                                      

LPDSP32 processor:

- `main.c`           : main file, containing the Fibonacci function as well 
                       as LPDSP32 memory allocation and interrupt handles
- `lpdsp32_init.S`   : assembly code that is used to initialize LPDSP32 
                       and its interrupts

Verification
------------
To validate that the sample app is working properly, debug the projects on 
both Arm Cortex-M3 core (ON Semiconductor IDE) and LPDSP32 (ChessDE), and
monitor the `fibonacciValue` variable. This variable shows a new Fibonacci
number calculated after each press of a (DIO5) button on the RSL10 Evaluation
and Development Board.

***
Copyright (c) 2019 Semiconductor Components Industries, LLC
(d/b/a ON Semiconductor).
